@@ -945,7 +945,6 @@ def mainloop(win):
 
     signal.signal(signal.SIGINT, lambda signum, frame: root.exit())
     signal.signal(signal.SIGTERM, lambda signum, frame: root.exit())
-    signal.signal(signal.SIGQUIT, lambda signum, frame: root.exit())
     # so it only shuts down after a full frame is rendered
     while True:
         winh, winw = win.getmaxyx()
@@ -990,6 +989,7 @@ def calc_first_frame(height, width):
 
 def main():
     try:
+        curses.setupterm("xterm-256color")
         stdscr = curses.initscr()
         curses.flushinp()
     except curses.error:
